/// <reference types="react" />
import * as React$1 from 'react';
import React__default, { HTMLAttributeAnchorTarget } from 'react';

interface AccordionProps {
    title: string | JSX.Element;
    isOpen?: boolean;
    isFixedAccordion?: boolean;
    isVerifiedToken?: boolean;
    extraIcon?: JSX.Element;
    children: React__default.ReactNode;
}
declare const MbAccordion: (props: AccordionProps) => JSX.Element;

declare enum EType {
    PRIMARY = "primary",
    SECONDARY = "secondary"
}
declare enum EState {
    ACTIVE = "active",
    CAUTION = "caution",
    DISABLED = "disabled",
    LOADING = "loading"
}
declare enum ESize {
    SMALL = "small",
    MEDIUM = "medium",
    BIG = "big"
}
declare enum ESmallCardType {
    PROFILE = "profile",
    STORE = "store"
}

interface ActionProps extends React__default.ButtonHTMLAttributes<HTMLButtonElement> {
    state?: EState.ACTIVE | EState.DISABLED | EState.CAUTION;
    size?: ESize;
}
declare const MbAction: ({ state, size, className, ...props }: ActionProps) => JSX.Element;

interface Item {
    content: JSX.Element;
    selected?: boolean;
    icon?: JSX.Element;
    onClick?: () => void;
}
interface DropdownMenuProps {
    items: Item[];
    isOpen: boolean;
    className?: string;
}
declare const MbDropdownMenu: (props: DropdownMenuProps) => JSX.Element | null;

interface ButtonProps extends React__default.ButtonHTMLAttributes<HTMLButtonElement> {
    label?: string | JSX.Element;
    btnType?: EType;
    state?: EState;
    size?: ESize;
    customClass?: string;
    dropDownItems?: Item[] | undefined;
}
declare const MbButton: ({ label, state, size, btnType, dropDownItems, customClass, ...props }: ButtonProps) => JSX.Element;

interface MbButtonProps {
    href?: string;
    icon: JSX.Element;
    text?: string;
    title?: string;
    cssClass?: string;
    target?: HTMLAttributeAnchorTarget;
    isNearSocial?: boolean;
}
declare const MbButtonLink: ({ href, icon, text, cssClass, target, title, isNearSocial }: MbButtonProps) => JSX.Element;

declare enum EIconName {
    CHECK = "check",
    VERIFIED = "verified",
    CLOSE = "close",
    ARROW_UP = "arrow_upward",
    ARROW_BACK = "arrow_back",
    ARROW_FORWARD = "arrow_forward",
    ARROW_DIAGONAL = "arrow_diagonal",
    MOON = "nightlight_round",
    SUN = "light_mode",
    TICKET = "local_activity",
    THREED = "3d_rotation",
    VIDEO = "videocam",
    FILE = "insert_drive_file",
    IMAGE = "image",
    AUDIO = "music_note",
    SHIFT = "shift",
    ORDER_BY = "order_by",
    COMPARE_ARROWS = "compare_arrows",
    FADERS = "faders",
    SHIELD_CHECK = "shield_check",
    CHARTPIE = "chartpie",
    SIMPLE_CREDIT_CARD = "simple_credit_card",
    CREDIT_CARD = "credit_card",
    TERMINAL = "terminal",
    FORWARD = "forward",
    REPORT = "report_problem",
    ARROW_DROP_DOWN = "arrow_drop_down",
    ARROW_DROP_UP = "arrow_drop_up",
    FULLSCREEN = "fullscreen",
    FULLSCREEN_EXIT = "fullscreen_exit",
    ROCKET = "rocket",
    SEND = "send",
    SELL = "sell",
    MULTIPLY = "multiply",
    BACKSPACE = "backspace",
    MORE = "more_horiz",
    DELETE = "delete_forever",
    DOWNLOAD = "download",
    BOOK = "book",
    SHARE = "share",
    SIMPLE_SHARE = "simple_share",
    HAND_COINS = "hand_coins",
    WALLET = "wallet",
    COINS = "coins",
    FLASH = "flash",
    HAND_RAISE = "hand_raise",
    HAND_SHAKE = "hand_shake",
    HOUSE = "house",
    ROBOT = "robot",
    MENU = "menu",
    SEARCH = "search",
    CIRCLE = "circle",
    NOTIFICATIONS = "notifications",
    ARROW_BACK_BIG = "arrow_back_ios",
    ARROW_FORWARD_BIG = "arrow_forward_ios",
    ARROW_BACK_SMALL = "navigate_before",
    ARROW_FORWARD_SMALL = "navigate_next",
    ARROW_EXPAND_MORE = "expand_more",
    ARROW_EXPAND_LESS = "expand_less",
    SELECT_ARROWS = "unfold_more",
    OPEN_NEW_TAB = "launch",
    LINK = "link",
    UNLINK = "link_off",
    LIKE = "favorite_border",
    LIKE_FILLED = "favorite",
    INFO = "info",
    ERROR = "error",
    SUCCESS = "check_circle",
    EDITIONS = "filter_none",
    EDIT = "edit",
    FILTERS = "filters",
    COPY = "copy",
    BURN = "local_fire_department",
    FACEBOOK = "facebook",
    INSTAGRAM = "instagram",
    PINTEREST = "pinterest",
    TWITTER = "twitter",
    TELEGRAM = "telegram",
    MEDIUM = "medium",
    LINKEDIN = "linkedin",
    YOUTUBE = "youtube",
    GITHUB = "github",
    DISCORD = "discord",
    MINTBASE = "mintbase",
    PLAY = "play",
    PAUSE = "pause",
    EYE = "eye",
    IMAGE_NOT_SUPPORTED = "image_not_supported",
    MINTBASE_DARK_BADGE = "mintbase_dark_badge",
    MINTBASE_LIGHT_BADGE = "mintbase_light_badge",
    PARAS_LIGHT_BADGE = "paras_badge_light",
    PARAS_DARK_BADGE = "paras_badge_dark",
    APOLLO42_LIGHT_BADGE = "apollo42_badge_light",
    APOLLO42_DARK_BADGE = "apollo42_badge_dark",
    FEWFAR_LIGHT_BADGE = "fewfar_badge_light",
    FEWFAR_DARK_BADGE = "fewfar_badge_dark",
    SATORI_LIGHT_BADGE = "satori_badge_light",
    SATORI_DARK_BADGE = "satori_badge_dark",
    TENK_LIGHT_BADGE = "tenk_badge_light",
    TENK_DARK_BADGE = "tenk_badge_dark",
    NEAR_SOCIAL = "near_social_icon",
    NEAR_SOCIAL_LONG = "near_social_long",
    WEB = "web",
    STABLES = "stables",
    USDC = "usdc",
    USDT = "usdt",
    NEAR = "near",
    NONE = "none",
    BLOCK = "block"
}

declare type TThingCard = {
    upperLeftIcon?: EIconName;
    upperLeftText?: string;
    upperRightElement?: JSX.Element;
    centerElement: JSX.Element;
    nftTypeIcon?: EIconName;
    extraMidLeftElement?: JSX.Element;
    midLeftText: string;
    midRightText: string;
    botLeftImage?: JSX.Element;
    botRightText?: string;
    botRightIcon?: EIconName;
    onUpperLeftClick?: (e?: React.MouseEvent<HTMLElement>) => void;
    onCenterElementClick?: (e?: React.MouseEvent<HTMLElement>) => void;
    onBotLeftImageClick?: (e?: React.MouseEvent<HTMLElement>) => void;
};
declare type TSmallCard = {
    centerElement: JSX.Element;
    title: string;
    subtitle?: string;
    onCardClick?: (e?: React.MouseEvent<HTMLElement>) => void;
};
declare type TInfoCard = {
    loading?: boolean;
    title: string;
    titleIcon?: JSX.Element;
    description?: string;
    upperIcon?: JSX.Element;
    descriptionIcon?: EIconName;
    descriptionImage?: string;
    lowerLeftText?: string;
    isBigDescription?: boolean;
    isNumber?: boolean;
    size?: ESize;
    isLink?: boolean;
    handleDescriptionClick?: (e?: React.MouseEvent<HTMLElement>) => void;
};

declare const MbInfoCard: ({ boxInfo }: {
    boxInfo: TInfoCard;
}) => JSX.Element;

interface CardProps$1 extends React__default.ComponentProps<'div'> {
    loading?: boolean;
    card: TSmallCard;
    cardType: ESmallCardType;
    isBigStoreCard?: boolean;
}
declare const MbSmallCard: ({ loading, cardType, card, isBigStoreCard, }: CardProps$1) => JSX.Element;

interface CardProps extends React__default.ComponentProps<'div'> {
    loading?: boolean;
    cardInfo: TThingCard;
}
declare const MbThingCard: ({ loading, cardInfo }: CardProps) => JSX.Element;

interface MetaCardHeaderProps {
    onMetaCardImageClick: () => void;
    nftTypeIcon?: EIconName;
    showCreditCardIcon?: boolean;
    metaCardImage: JSX.Element;
}
interface MetaCardInfoProps {
    storeNameElement: JSX.Element;
    nftTitle: string;
    minterImage: JSX.Element;
    tokenListings: string;
    priceWidget: JSX.Element;
    onMinterImageClick: (e: any) => any;
}
interface MetaCardProps extends React__default.ComponentProps<'li'> {
    loading?: boolean;
    metaCardHeaderData: MetaCardHeaderProps;
    metaCardInfo: MetaCardInfoProps;
}
declare const MbMetaCard: ({ loading, metaCardInfo, metaCardHeaderData, }: MetaCardProps) => JSX.Element;

declare const MbIcon: ({ name, color, darkColor, size, height, className, }: {
    name: EIconName;
    color: string;
    darkColor?: string | undefined;
    size?: string | undefined;
    height?: string | undefined;
    className?: string | undefined;
}) => JSX.Element;

declare enum EControlStatus {
    NORMAL = "normal",
    VALID = "valid",
    INVALID = "invalid"
}
interface InputProps extends React__default.InputHTMLAttributes<HTMLInputElement> {
    label?: string;
    hasIcon?: boolean;
    controlStatus: EControlStatus;
    inputSize?: ESize;
    hasPercentageLabel?: boolean;
    maxChars?: number;
    initialCounter?: number;
    defaultValue?: number | undefined;
    customIcon?: JSX.Element;
}
declare const MbInput: React__default.ForwardRefExoticComponent<InputProps & React__default.RefAttributes<HTMLInputElement>>;

interface TextareaProps extends React.TextareaHTMLAttributes<HTMLTextAreaElement> {
    label?: string;
    controlStatus: EControlStatus;
    inputSize?: ESize;
    maxChars?: number;
    initialCounter?: number;
}
declare const MbTextArea: React$1.ForwardRefExoticComponent<TextareaProps & React$1.RefAttributes<HTMLTextAreaElement>>;

interface InputTagsProps extends React.InputHTMLAttributes<HTMLInputElement> {
    label: string;
    maxTags: number;
    inputSize?: ESize;
    onTagsChange: (tags: string[]) => void;
    onMaxTags: () => void;
}
declare const MbInputTags: React$1.ForwardRefExoticComponent<InputTagsProps & React$1.RefAttributes<HTMLInputElement>>;

interface SelectProps extends React.SelectHTMLAttributes<HTMLSelectElement> {
    options: TSelectOption[];
    onValueChange: (value: string) => void;
    value?: string;
}
declare type TSelectOption = {
    value: string;
    label: string;
};
declare const MbInputSelect: (props: SelectProps) => JSX.Element;

declare const MbItemsPerPage: ({ onItemsPage, currentValue, }: {
    onItemsPage: (page: number) => void;
    currentValue: number;
}) => JSX.Element;

interface PaginationProps {
    onPageChange: (currentPage: number) => void;
    totalItems: number;
    currentPage: any;
    itemsPerPage: number;
    hasLabel?: boolean;
}
declare const MbPagination: (props: PaginationProps) => JSX.Element | null;

interface TableProps extends React__default.HTMLAttributes<HTMLDivElement> {
    tableTitle?: string | JSX.Element;
    pagination?: PaginationProps;
    showItemsPerPage?: boolean;
    onAmountItemsChange?: (page: number) => void;
    loading?: boolean;
    checkboxElements?: {
        id: number;
        content: JSX.Element;
    }[];
}
declare const MbHead: (props: React__default.HTMLAttributes<HTMLDivElement>) => JSX.Element;
declare const MbBody: (props: React__default.HTMLAttributes<HTMLDivElement> & {
    loading?: boolean;
    colsAmount?: number;
}) => JSX.Element;
declare const MbTable: (props: TableProps) => JSX.Element;

interface TabProps extends React__default.HTMLAttributes<HTMLDivElement> {
    label: JSX.Element;
    isActive?: boolean;
    isSmall?: boolean;
    extraFilter?: string;
    isExtraFilterSelected?: boolean;
    onExtraFilterChange?: (isSelected: boolean) => void;
}
declare const MbTab: (props: TabProps) => JSX.Element;

interface TabsProps extends React__default.HTMLAttributes<HTMLDivElement> {
    activeIndex: number;
    filterOptions?: TFilterOptions;
    firstElement?: JSX.Element;
    onTabChange: (index: number) => void;
    onOrderByChange: (selected: string) => void;
}
declare type TFilterOptions = {
    label: string;
    defaultOptionId?: string;
    options: {
        id: string;
        label: string;
    }[];
};
declare const MbTabs: (props: TabsProps) => JSX.Element;

declare type SemanticHtmlTextTypes = 'h1' | 'h2' | 'h3' | 'h4' | 'h5' | 'h6' | 'p' | 'span' | 'em';
declare type TextProps = {
    semanticHtmlTag?: SemanticHtmlTextTypes;
} & React__default.HTMLAttributes<HTMLDivElement>;
declare const MbText: (props: TextProps) => JSX.Element;

declare const MbTooltip: ({ text, component, pos, classname, }: {
    text: string;
    component: JSX.Element;
    pos: string;
    classname?: string | undefined;
}) => JSX.Element;

interface LogoProps {
    src: string;
    width?: string;
    className?: string;
}
declare const MbLogo: ({ src, width, className, }: LogoProps) => JSX.Element;

interface MbStatefulButtonProps {
    indicator: JSX.Element;
    content: JSX.Element;
    className?: string;
    hasEmptyStatus?: boolean;
    onClick?: React__default.MouseEventHandler<HTMLDivElement>;
}
declare const MbStatefulButton: ({ indicator, content, className, hasEmptyStatus, onClick, }: MbStatefulButtonProps) => JSX.Element;

declare const MbSwitch: React$1.ForwardRefExoticComponent<ToggleProps & React$1.RefAttributes<HTMLInputElement>>;

declare const MbCheckbox: React$1.ForwardRefExoticComponent<ToggleProps & React$1.RefAttributes<HTMLInputElement>>;

interface ChipProps extends ToggleProps {
    isChecked: boolean;
    disabled: boolean;
    handleClick: () => void;
}
declare const MbChip: (props: ChipProps) => JSX.Element;

declare const MbRadioButton: React$1.ForwardRefExoticComponent<ToggleProps & React$1.RefAttributes<HTMLInputElement>>;

interface ModalProps extends React.HTMLAttributes<HTMLDivElement> {
    topTitle: string | JSX.Element;
    subtitle?: string;
    topElement?: JSX.Element;
    topElementFirst?: boolean;
    open: boolean;
    onClose: () => void;
}
declare const MbModal: (props: ModalProps) => JSX.Element;

interface MediaImportProps {
    isProfileImage?: boolean;
    isHeaderImage?: boolean;
    acceptedFormats: string[];
    idealDimensions: string;
    uploadedFile: File;
    placeholderImageURL?: string;
    handleFileAdd: (file: File) => void;
    handleFileRemove: () => void;
    maxFileSize?: number;
}
declare const MbMediaImport: (props: MediaImportProps) => JSX.Element;

interface InputAccountProps {
    subtitle: string;
    smallSubtitle: string;
    inputs: JSX.Element;
    footer: JSX.Element;
}
declare const MbInputAccount: (props: InputAccountProps) => JSX.Element;

interface AmountButtonProps extends React.InputHTMLAttributes<HTMLInputElement> {
    maxAmount: number;
    btnSize?: ESize;
    controlStatus?: EControlStatus;
    onValueChange: (amount: string) => void;
}
declare const MbAmountInput: React$1.ForwardRefExoticComponent<AmountButtonProps & React$1.RefAttributes<HTMLInputElement>>;

declare type TNetworkOption = {
    label: string;
    value: string;
    indicator: JSX.Element;
};

interface NetworkMenuProps {
    options: TNetworkOption[];
    isOpen?: boolean;
    isInline?: boolean;
    menuClassName?: string;
    itemClassName?: string;
    onOptionChange: (selected: string) => void;
}
declare const MbNetworkMenu: (props: NetworkMenuProps) => JSX.Element | null;

interface MenuWrapperProps extends React.HTMLAttributes<HTMLDivElement> {
    setIsOpen: React.Dispatch<React.SetStateAction<boolean>>;
}
declare const MbMenuWrapper: (props: MenuWrapperProps) => JSX.Element;

interface ColorIndicatorProps {
    parentClassName?: string;
    childClassName?: string;
}
declare const MbColorIndicator: (props: ColorIndicatorProps) => JSX.Element;

declare const MbAudioPlayer: ({ src }: {
    src: string;
}) => JSX.Element;

declare const MbModelPlayer: ({ modelSrc, posterImg, ...restProps }: {
    modelSrc: string;
    posterImg: JSX.Element;
}) => JSX.Element;

declare const MbVideoPlayer: ({ src, type, }: {
    src: string;
    type: string;
}) => JSX.Element;

declare type TColorDetail = {
    sectionTitle: string;
    colors: TColor[];
};
declare type TColor = {
    class: string;
    hex: string;
};

interface ToggleProps extends React.InputHTMLAttributes<HTMLInputElement> {
    label?: string;
}

declare type TInputState = {
    amount: {
        value: number;
        valid: boolean;
    };
    account: {
        value: string;
        valid: boolean;
    };
    editable: boolean;
    cleared: boolean;
    value?: string;
};
declare type TNearAccountState = {
    account: {
        value: string;
        valid: boolean;
    };
    cleared: boolean;
};

declare const MbNearAmountAccount: ({ subtitle, smallSubtitle, defaultState, accountExists, defaultAccountsCounter, initialUsedAmount, saveButton, isPercentage, sendFinalState, isValidInfo, totalAmount, transferTemplate, isStoreSettings, dropdownItems, usedAmount, maxAmountPerAccount, allowEmptyState, }: {
    subtitle: string;
    smallSubtitle: string;
    defaultState: Record<string, TInputState>;
    accountExists: (account: string) => Promise<boolean>;
    defaultAccountsCounter: number;
    initialUsedAmount?: number | undefined;
    saveButton?: {
        text: string;
        save: () => boolean;
    } | undefined;
    isPercentage?: boolean | undefined;
    sendFinalState?: ((state: Record<string, TInputState>) => void) | undefined;
    isValidInfo?: ((valid: boolean) => void) | undefined;
    totalAmount: number;
    transferTemplate?: {
        available: number;
    } | undefined;
    isStoreSettings?: boolean | undefined;
    dropdownItems?: Item[] | undefined;
    usedAmount?: ((amount: number) => void) | undefined;
    maxAmountPerAccount?: number | undefined;
    allowEmptyState?: boolean | undefined;
}) => JSX.Element;

declare const MbAmountAccountInput: ({ id, validateAccount, validateAmount, handleChangeAmount, handleChangeAccount, handleRemoveItem, isPercentage, isCleared, prefillAmount, }: {
    id: string;
    validateAmount: (id: any, amount: number) => boolean;
    validateAccount: (id: any, value: string) => Promise<boolean>;
    handleChangeAmount: (id: string, amount: number) => void;
    handleChangeAccount: (id: string, account: string) => Promise<void>;
    handleRemoveItem: (id: string) => void;
    isPercentage?: boolean | undefined;
    isCleared?: boolean | undefined;
    prefillAmount: number | null;
}) => JSX.Element;

declare const MbRowSelectList: ({ elements, dropdownItems, deleteRow, addMinters, removeMinters, }: {
    elements: {
        id: string;
        content: JSX.Element;
        isDisabled: boolean;
    }[];
    dropdownItems?: Item[] | undefined;
    deleteRow: (id: string) => void;
    addMinters: () => void;
    removeMinters: (ids: string[]) => void;
}) => JSX.Element;

declare const MbNearAccountList: ({ subtitle, smallSubtitle, accountExists, saveButton, dropdownItems }: {
    subtitle: string;
    smallSubtitle: string;
    accountExists: (account: string) => Promise<boolean>;
    saveButton?: {
        text: string;
        save: (accounts: string[]) => void;
    } | undefined;
    dropdownItems?: Item[] | undefined;
}) => JSX.Element;

declare enum EPillTemplate {
    BLACK = "black",
    PURPLE = "purple",
    BLUE = "blue",
    GREEN = "green",
    RED = "red",
    ORANGE = "orange"
}

declare const MbPill: ({ text, pillTemplate, }: {
    text: string;
    pillTemplate: EPillTemplate;
}) => JSX.Element;

interface ChipsProps extends React__default.HTMLAttributes<HTMLElement> {
    removeTag: () => void;
}
declare const MbTag: (props: ChipsProps) => JSX.Element;

interface ArrowMenuProps {
    title: string;
    isActive?: boolean;
}
declare const MbArrowMenu: (props: ArrowMenuProps) => JSX.Element;

interface DropdownHoverMenuProps {
    className?: string;
    dropdownButton: JSX.Element;
    children: JSX.Element;
}
declare const MbDropdownHoverMenu: (props: DropdownHoverMenuProps) => JSX.Element;

declare const colorsArray: TColorDetail[];

declare const getFontType: (size: string) => "p-big-90" | "p-med-90" | "p-small-90";
declare const getInputLabelFontType: (inputSize: string) => "p-med-90" | "p-small-90" | "cap-big-90" | undefined;

declare const AUDIO_TYPES: string[];
declare const VIDEO_TYPES: string[];
declare const IMAGE_TYPES: string[];
declare const THREED_TYPES: string[];
declare const FILE_TYPES: string[];
declare const ALL_TYPES: string[];

declare const MbActionText: ({ size, text, copyText, iconTab, iconCopy, link, }: {
    size: ESize;
    text: string;
    copyText?: string | undefined;
    iconTab?: boolean | undefined;
    iconCopy?: boolean | undefined;
    link?: string | undefined;
}) => JSX.Element;

declare enum ScreenBreakpoint {
    SM = "sm",
    MD = "md",
    LG = "lg",
    XL = "xl"
}
declare type TScreenBreakpoint = ScreenBreakpoint.LG | ScreenBreakpoint.MD | ScreenBreakpoint.SM | ScreenBreakpoint.XL;
declare const getBreakpointValue: (value: ScreenBreakpoint) => number;
declare const getCurrentBreakpoint: () => TScreenBreakpoint;

export { ALL_TYPES, AUDIO_TYPES, EControlStatus, EIconName, EPillTemplate, ESize, ESmallCardType, EState, EType, FILE_TYPES, IMAGE_TYPES, Item, MbAccordion, MbAction, MbActionText, MbAmountAccountInput, MbAmountInput, MbArrowMenu, MbAudioPlayer, MbBody, MbButton, MbButtonLink, MbCheckbox, MbChip, MbColorIndicator, MbDropdownHoverMenu, MbDropdownMenu, MbHead, MbIcon, MbInfoCard, MbInput, MbInputAccount, MbInputSelect, MbInputTags, MbItemsPerPage, MbLogo, MbMediaImport, MbMenuWrapper, MbMetaCard, MbModal, MbModelPlayer, MbNearAccountList, MbNearAmountAccount, MbNetworkMenu, MbPagination, MbPill, MbRadioButton, MbRowSelectList, MbSmallCard, MbStatefulButton, MbSwitch, MbTab, MbTable, MbTabs, MbTag, MbText, MbTextArea, MbThingCard, MbTooltip, MbVideoPlayer, ScreenBreakpoint, TColor, TColorDetail, THREED_TYPES, TInfoCard, TInputState, TNearAccountState, TNetworkOption, TScreenBreakpoint, TSmallCard, TThingCard, ToggleProps, VIDEO_TYPES, colorsArray, getBreakpointValue, getCurrentBreakpoint, getFontType, getInputLabelFontType };
